@@ -1,13 +1,13 @@
-mod config;
-mod pam;
+mod logic;
 mod yubi;
 mod zfs_mount;
 
+use crate::zfs_mount::zfs_mount;
 use clap::{crate_authors, crate_version, App, Arg};
+use sha2::{Digest, Sha512};
 use std::{env, process::exit};
 
-use crate::config::{config_mode_file, config_mode_yubi, unlock_zfs_file, unlock_zfs_yubi};
-use crate::pam::{pam_mode_file, pam_mode_yubi};
+use crate::logic::{print_mode_file, print_mode_yubi, unlock_zfs_file, unlock_zfs_yubi};
 
 fn main() {
     let app = App::new("shavee")
@@ -23,7 +23,7 @@ fn main() {
                 .takes_value(false),
         )
         .arg(
-            Arg::with_name("pfile")
+            Arg::with_name("keyfile")
                 .short("f")
                 .long("file")
                 .help("<Keyfile location>")
@@ -57,44 +57,59 @@ fn main() {
             eprintln!("ERROR: Specify base home dir with -z eg. \"zroot/data/home/\"");
             exit(1)
         };
-        if arg.is_present("pfile") {
-            pam_mode_file(
-                &pass,
-                &arg.value_of("dir").expect("Invalid base dir.").to_string(),
-                &arg.value_of("pfile").expect("Invalid File.").to_string(),
+
+        let mut dir = arg.value_of("dir").expect("Invalid dir").to_string();
+        if !dir.ends_with('/') {
+            dir.push('/');
+        };
+
+        let user = env::var("PAM_USER").expect("Var not found");
+        dir.push_str(user.as_str());
+
+        if arg.is_present("keyfile") {
+            unlock_zfs_file(
+                pass,
+                arg.value_of("keyfile").expect("Invalide File").to_string(),
+                dir,
             )
         } else if arg.is_present("yubikey") {
-            pam_mode_yubi(
-                &pass,
-                &arg.value_of("dir").expect("Invalid base dir.").to_string(),
-            );
+            unlock_zfs_yubi(pass, dir)
         } else {
-            eprintln!("ERROR: Select a 2FA mode with either -y (Yubikey) or -f (File)");
-            exit(1);
+            let key = Sha512::digest(pass.as_bytes());
+            zfs_mount(
+                &format!("{:x}", key),
+                arg.value_of("dir").expect("Invalid Dataset").to_string(),
+            );
         }
     } else {
         if arg.is_present("dir") {
             if arg.is_present("yubikey") {
                 unlock_zfs_yubi(pass, arg.value_of("dir").unwrap().to_string())
-            } else if arg.is_present("pfile") {
+            } else if arg.is_present("keyfile") {
                 unlock_zfs_file(
                     pass,
-                    arg.value_of("pfile").expect("Invalid File.").to_string(),
+                    arg.value_of("keyfile").expect("Invalid File.").to_string(),
                     arg.value_of("dir")
                         .expect("Invalid Dataset input.")
                         .to_string(),
                 )
+            } else {
+                let key = Sha512::digest(pass.as_bytes());
+                zfs_mount(
+                    &format!("{:x}", key),
+                    arg.value_of("dir").expect("Invalid Dataset").to_string(),
+                );
             }
-        } else if arg.is_present("pfile") {
-            config_mode_file(
+        } else if arg.is_present("keyfile") {
+            print_mode_file(
                 &pass,
-                &arg.value_of("pfile").expect("Invalid File.").to_string(),
+                &arg.value_of("keyfile").expect("Invalid File.").to_string(),
             );
         } else if arg.is_present("yubikey") {
-            config_mode_yubi(&pass);
+            print_mode_yubi(&pass);
         } else {
-            eprintln!("Select a 2FA mode with either -y (Yubikey) or -f (File)");
-            exit(1)
+            let key = Sha512::digest(pass.as_bytes());
+            println!("{:x}", key);
         }
     }
 }
